import { Expr, FuncType, LocalVariables, Module, ValueType } from './wasm';
declare enum FuncMode {
    Active = 0,
    NotActive = 1
}
interface Func {
    mode: FuncMode;
    name?: string;
    locals: LocalVariables;
    localsCount: number;
    type: FuncType;
    code: Expr;
}
interface Local {
    index: number;
}
export declare function createFunction(type: FuncType, code: Expr): {
    mode: FuncMode;
    locals: never[];
    localsCount: number;
    type: FuncType;
    code: Expr;
};
/**
 * Creates new, empty module
 *
 * @returns Empty, initialized module.
 */
export declare function createModule(): Module;
/**
 * Takes in a module and adds a function to it.
 *
 * Note: Once a function is added to a module, you cannot reuse it.
 * This is to prevent users from adding it to a module then editing
 * the function further and wondering why the changes are not showing up.
 *
 * If a name is provided, we generate an export with that name
 *
 * @param module - A WebAssembly Module
 * @param func - The function
 * @returns Module with new function.
 */
export declare function addFunction(module: Module, func: Func): Module;
export declare function addLocal(func: Func, type: ValueType): Local;
export {};
